@@ -1,3 +1,4 @@
+from urllib.parse import urlparse
 from collections import namedtuple
 from django.views.generic import TemplateView, View
 from django.template.loader import render_to_string
@@ -123,13 +124,15 @@ class MenuItem(BaseMenuItem):
         super().__init__(**kwargs)
         self._resolved_url = None
         self.link_type = link_type
-        split_url = url.split(',') if url else [None]
-        if url_args is None and len(split_url) > 1:
-            url_args = split_url[1:]
-        self._href = self.raw_href(split_url[0], url_args, url_kwargs)
+        if self.link_type in [self.URL_NAME, self.AJAX_GET_URL_NAME]:
+            split_url = url.split(',') if url else [None]
+            if url_args is None and len(split_url) > 1:
+                url_args = split_url[1:]
+                url = split_url[0]
+        self._href = self.raw_href(url, url_args, url_kwargs)
         self._attributes = attributes
         self.menu_config = {}
-        if url is not None and link_type in self.RESOLVABLE_LINK_TYPES:
+        if url is not None and link_type in self.RESOLVABLE_LINK_TYPES and self.resolved_url != 'invalid':
             view_class = self.resolved_url.func.view_class
             if not menu_display:
                 if hasattr(view_class, 'menu_display'):
@@ -183,7 +186,10 @@ class MenuItem(BaseMenuItem):
     @property
     def resolved_url(self):
         if self._resolved_url is None:
-            self._resolved_url = resolve(self._href)
+            try:
+                self._resolved_url = resolve(urlparse(self._href).path)
+            except Resolver404:
+                self._resolved_url = 'invalid'
         return self._resolved_url
 
     def params(self):
